package Fairness.Graphing;

import edu.rit.numeric.plot.Label;
import edu.rit.swing.Displayable;
import org.gillius.Util.CheckUtils;

import java.awt.*;
import java.awt.geom.AffineTransform;
import java.awt.geom.Rectangle2D;

/**
 * LegendItem draws a single piece of a graph's legend by drawing a dot with a label.
 *
 * @author Jason Winnebeck
 */
public class LegendItem implements Displayable {
    private final PlotSeriesInfo info;
    private final Label label;

    /**
     * Constructs a new LegendItem to display a legend fragment for a series to be drawn with the
     * given PlotSeriesInfo and the name of the series.
     *
     * @param info non-null PlotSeriesInfo
     * @param name non-null name
     */
    public LegendItem( PlotSeriesInfo info, String name ) {
        CheckUtils.checkNull( info, "info" );
        CheckUtils.checkNull( name, "name" );

        this.info = info;
        label = new Label( name, 10.0, 5.0, Label.RIGHT );
    }

    /**
     * Returns this displayable object's bounding box. This is the smallest rectangle that encloses
     * all of this displayable object.
     * <p/>
     * Currently this is hardcoded because we can't tell how big the label will be.
     */
    public Rectangle2D getBoundingBox() {
        return new Rectangle( 0, 0, 100, 20 );
    }

    /**
     * Returns this displayable object's background paint.
     */
    public Paint getBackgroundPaint() {
        return Color.WHITE;
    }

    /**
     * Draw this drawable object in the given graphics context. Upon return from this method, the
     * given graphics context's state (color, font, transform, clip, and so on) is the same as it
     * was upon entry to this method.
     *
     * @param g2d 2-D graphics context.
     */
    public void draw( Graphics2D g2d ) {
        AffineTransform old = g2d.getTransform();

        g2d.translate( 5, 5 );
        info.getDots().draw( g2d );
        g2d.setTransform( old );

        g2d.translate( label.getLocationX(), label.getLocationY() );
        label.draw( g2d );
        g2d.setTransform( old );
    }
}
