package Fairness.Graphing;

import edu.rit.numeric.XYSeries;
import edu.rit.numeric.plot.XYPlotSeries;
import edu.rit.swing.Drawable;
import org.gillius.Util.CheckUtils;

import java.awt.*;

/**
 * PlotSeriesInfo provides style information (dots, stroke, and paint) for drawing a single series
 * on a {@link Graph}.
*
* @author Jason Winnebeck
*/
class PlotSeriesInfo {
    private final Drawable dots;
    private final Stroke stroke;
    private final Paint paint;

    /**
     * Constructs a new PlotSeriesInfo
     * @param dots   non-null Drawable for data markers
     * @param stroke non-null stroke for the line
     * @param paint  non-null paint(color) for the line
     */
    public PlotSeriesInfo( Drawable dots, Stroke stroke, Paint paint ) {
        CheckUtils.checkNull( dots, "dots" );
        CheckUtils.checkNull( stroke, "stroke" );
        CheckUtils.checkNull( paint, "paint" );

        this.dots   = dots;
        this.stroke = stroke;
        this.paint  = paint;
    }

    public Drawable getDots() {
        return dots;
    }

    public Stroke getStroke() {
        return stroke;
    }

    public Paint getPaint() {
        return paint;
    }

    /**
     * Constructs a new XYPlotSeries with the given data and styles it with the style of this
     * PlotSeriesInfo.
     *
     * @param series non-null XYSeries of data
     * @return non-null new XYPlotSeries
     */
    XYPlotSeries makePlotSeries( XYSeries series ) {
        CheckUtils.checkNull( series, "series" );

        return new XYPlotSeries( series, dots, stroke, paint );
    }

    /**
     * Creates a new LegendItem to display a legend fragment for the given data series.
     *
     * @param series non-null NamedXYSeries of data
     * @return non-null new LegendItem
     */
    LegendItem makeLegendItem( NamedXYSeries series ) {
        return new LegendItem( this, series.getName() );
    }
}
