package Fairness;

import Fairness.Nodes.NodePacket;
import Fairness.Nodes.Node;

/**
 * NodeTransferEvent performs a single time, one-off arrival of a NodePacket at a Node.
 *
 * @author Jason Winnebeck
 */
public class NodeTransferEvent implements SimulationEvent {
    private final NodePacket packet;
    private final Node dest;

    /**
     * Constructs a new NodeTransferEvent to deliver the given packet to the given Node when the
     * event is fired.
     */
    public NodeTransferEvent( NodePacket packet, Node dest ) {
        this.packet = packet;
        this.dest = dest;
    }

    /**
     * Performs the event that is occuring within a {@link Fairness.Simulation}. If an event wishes
     * to re-execute later, it may schedule itself again using the provided Simulation reference.
     *
     * @param sim  non-null Simulation
     * @param time simulation time
     */
    public void perform( Simulation sim, double time ) {
        dest.processPacket( sim, packet );
    }
}
