package Fairness.Publishers;

/**
 * Publisher represents the source of taxation in the system.
 * <p/>
 * This class is not used in the current implementation as taxation was not implemented.
 *
 * @author Jason Winnebeck
 */
public abstract class Publisher {
    private final int availableStripes;

    /**
     * Constructs a new Publisher that splits its content into the given number of stripes.
     */
    protected Publisher( int availableStripes ) {
        this.availableStripes = availableStripes;
    }

    /**
     * Returns the number of stripes available from this Publisher.
     */
    public int getAvailableStripes() {
        return availableStripes;
    }

    /**
     * Returns the number of children that a node must accept for fowarding a single stream to
     * receive the given number of stripes.
     *
     * @param r Number of stripes to receive, must be greater than 0 and less than or equal the
     *          number of total available stripes.
     *
     * @return The number of children that a node must accept to receive the benefit.
     */
    public int getTax( int r ) {
        if ( r < 1 || r > availableStripes ) {
            throw new IllegalArgumentException( "Parameter r to Publisher.getTax must be within " +
                                                "the range 1-" + availableStripes +
                                                ", inclusive; " +
                                                "its value is " + r + '.' );
        }

        return getTaxImpl( r );
    }

    /**
     * Implements precisely the getTax method, except that the child class can assume the
     * preconditions on r have been checked.
     *
     * @see #getTax(int)
     */
    protected abstract int getTaxImpl( int r );
}
