package Fairness;

import Fairness.Nodes.Node;
import Fairness.Nodes.NodePacket;
import Fairness.Nodes.NodeBehaviors.SimpleNodeBehavior;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 * NodeMonitoringTest
 *
 * @author Jason Winnebeck
 */
public class NodeMonitoringTest {
    @Test
    public void testMonitoring() {
        NodeMonitor monitor = new NodeMonitor();

        Simulation sim = new Simulation( new SimulationParameters( 1, 1024, 512, 100.0, 0 ) );
        Node n = new Node( sim, 0, 100, 100, monitor, new SimpleNodeBehavior(),
                           new NoTreeBehavior() );

        n.makeTreeInfo( 0 );

        int lost = 0;
        int sent = 100;
        while ( sent > 0 ) {
            for ( int i = 0; i < lost; ++i ) {
                NodePacket p = new NodePacket( null, 0, true, false, 100 );
                n.processPacket( sim, p );
            }

            for ( int i = 0; i < sent; ++i ) {
                NodePacket p = new NodePacket( null, 0, false, true, 100 );
                n.processPacket( sim, p );
            }

            monitor.mark();

            sent -= 10;
            lost += 10;
        }

        assertEquals( 10, monitor.getMarks().size() );

        lost = 0;
        sent = 100;
        double expectedPercent = 1.0;
        for ( NodeMonitor.Mark mark : monitor.getMarks() ) {
            assertEquals( lost, mark.getLost() );
            assertEquals( sent, mark.getReceived() );
            assertEquals( lost + sent, mark.getTotal() );

            assertEquals( expectedPercent, mark.getReceivedPercent(), 0.00001 );
            assertEquals( 1.0-expectedPercent, mark.getLostPercent(), 0.00001 );

            sent -= 10;
            lost += 10;
            expectedPercent -= 0.1;
        }
    }
}
